@@ -13,10 +13,36 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_codedeploy.literals import (
+    AutoRollbackEvent,
+    BundleType,
+    ComputePlatform,
+    DeploymentCreator,
+    DeploymentOption,
+    DeploymentReadyAction,
+    DeploymentStatus,
+    DeploymentTargetType,
+    DeploymentType,
+    EC2TagFilterType,
+    ErrorCode,
+    FileExistsBehavior,
+    GreenFleetProvisioningAction,
+    InstanceAction,
+    InstanceStatus,
+    InstanceType,
+    LifecycleErrorCode,
+    LifecycleEventStatus,
+    MinimumHealthyHostsType,
+    OutdatedInstancesStrategy,
+    RevisionLocationType,
+    StopStatus,
+    TagFilterType,
+    TargetLabel,
+    TargetStatus,
+    TrafficRoutingType,
+    TriggerEventType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -137,19 +163,14 @@ ApplicationInfoTypeDef = TypedDict(
         "createTime": datetime,
         "linkedToGitHub": bool,
         "gitHubAccountName": str,
-        "computePlatform": Literal["Server", "Lambda", "ECS"],
+        "computePlatform": ComputePlatform,
     },
     total=False,
 )
 
 AutoRollbackConfigurationTypeDef = TypedDict(
     "AutoRollbackConfigurationTypeDef",
-    {
-        "enabled": bool,
-        "events": List[
-            Literal["DEPLOYMENT_FAILURE", "DEPLOYMENT_STOP_ON_ALARM", "DEPLOYMENT_STOP_ON_REQUEST"]
-        ],
-    },
+    {"enabled": bool, "events": List[AutoRollbackEvent]},
     total=False,
 )
 
@@ -169,7 +190,7 @@ BlueGreenDeploymentConfigurationTypeDef = TypedDict(
 
 BlueInstanceTerminationOptionTypeDef = TypedDict(
     "BlueInstanceTerminationOptionTypeDef",
-    {"action": Literal["TERMINATE", "KEEP_ALIVE"], "terminationWaitTimeInMinutes": int},
+    {"action": InstanceAction, "terminationWaitTimeInMinutes": int},
     total=False,
 )
 
@@ -180,9 +201,7 @@ CloudFormationTargetTypeDef = TypedDict(
         "targetId": str,
         "lastUpdatedAt": datetime,
         "lifecycleEvents": List["LifecycleEventTypeDef"],
-        "status": Literal[
-            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
-        ],
+        "status": TargetStatus,
         "resourceType": str,
         "targetVersionWeight": float,
     },
@@ -196,7 +215,7 @@ DeploymentConfigInfoTypeDef = TypedDict(
         "deploymentConfigName": str,
         "minimumHealthyHosts": "MinimumHealthyHostsTypeDef",
         "createTime": datetime,
-        "computePlatform": Literal["Server", "Lambda", "ECS"],
+        "computePlatform": ComputePlatform,
         "trafficRoutingConfig": "TrafficRoutingConfigTypeDef",
     },
     total=False,
@@ -218,14 +237,14 @@ DeploymentGroupInfoTypeDef = TypedDict(
         "alarmConfiguration": "AlarmConfigurationTypeDef",
         "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
         "deploymentStyle": "DeploymentStyleTypeDef",
-        "outdatedInstancesStrategy": Literal["UPDATE", "IGNORE"],
+        "outdatedInstancesStrategy": OutdatedInstancesStrategy,
         "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
         "loadBalancerInfo": "LoadBalancerInfoTypeDef",
         "lastSuccessfulDeployment": "LastDeploymentInfoTypeDef",
         "lastAttemptedDeployment": "LastDeploymentInfoTypeDef",
         "ec2TagSet": "EC2TagSetTypeDef",
         "onPremisesTagSet": "OnPremisesTagSetTypeDef",
-        "computePlatform": Literal["Server", "Lambda", "ECS"],
+        "computePlatform": ComputePlatform,
         "ecsServices": List["ECSServiceTypeDef"],
     },
     total=False,
@@ -240,24 +259,14 @@ DeploymentInfoTypeDef = TypedDict(
         "deploymentId": str,
         "previousRevision": "RevisionLocationTypeDef",
         "revision": "RevisionLocationTypeDef",
-        "status": Literal[
-            "Created", "Queued", "InProgress", "Baking", "Succeeded", "Failed", "Stopped", "Ready"
-        ],
+        "status": DeploymentStatus,
         "errorInformation": "ErrorInformationTypeDef",
         "createTime": datetime,
         "startTime": datetime,
         "completeTime": datetime,
         "deploymentOverview": "DeploymentOverviewTypeDef",
         "description": str,
-        "creator": Literal[
-            "user",
-            "autoscaling",
-            "codeDeployRollback",
-            "CodeDeploy",
-            "CodeDeployAutoUpdate",
-            "CloudFormation",
-            "CloudFormationRollback",
-        ],
+        "creator": DeploymentCreator,
         "ignoreApplicationStopFailures": bool,
         "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
         "updateOutdatedInstancesOnly": bool,
@@ -268,9 +277,9 @@ DeploymentInfoTypeDef = TypedDict(
         "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
         "loadBalancerInfo": "LoadBalancerInfoTypeDef",
         "additionalDeploymentStatusInfo": str,
-        "fileExistsBehavior": Literal["DISALLOW", "OVERWRITE", "RETAIN"],
+        "fileExistsBehavior": FileExistsBehavior,
         "deploymentStatusMessages": List[str],
-        "computePlatform": Literal["Server", "Lambda", "ECS"],
+        "computePlatform": ComputePlatform,
         "externalId": str,
         "relatedDeployments": "RelatedDeploymentsTypeDef",
     },
@@ -292,28 +301,20 @@ DeploymentOverviewTypeDef = TypedDict(
 
 DeploymentReadyOptionTypeDef = TypedDict(
     "DeploymentReadyOptionTypeDef",
-    {
-        "actionOnTimeout": Literal["CONTINUE_DEPLOYMENT", "STOP_DEPLOYMENT"],
-        "waitTimeInMinutes": int,
-    },
+    {"actionOnTimeout": DeploymentReadyAction, "waitTimeInMinutes": int},
     total=False,
 )
 
 DeploymentStyleTypeDef = TypedDict(
     "DeploymentStyleTypeDef",
-    {
-        "deploymentType": Literal["IN_PLACE", "BLUE_GREEN"],
-        "deploymentOption": Literal["WITH_TRAFFIC_CONTROL", "WITHOUT_TRAFFIC_CONTROL"],
-    },
+    {"deploymentType": DeploymentType, "deploymentOption": DeploymentOption},
     total=False,
 )
 
 DeploymentTargetTypeDef = TypedDict(
     "DeploymentTargetTypeDef",
     {
-        "deploymentTargetType": Literal[
-            "InstanceTarget", "LambdaTarget", "ECSTarget", "CloudFormationTarget"
-        ],
+        "deploymentTargetType": DeploymentTargetType,
         "instanceTarget": "InstanceTargetTypeDef",
         "lambdaTarget": "LambdaTargetTypeDef",
         "ecsTarget": "ECSTargetTypeDef",
@@ -324,26 +325,12 @@ DeploymentTargetTypeDef = TypedDict(
 
 DiagnosticsTypeDef = TypedDict(
     "DiagnosticsTypeDef",
-    {
-        "errorCode": Literal[
-            "Success",
-            "ScriptMissing",
-            "ScriptNotExecutable",
-            "ScriptTimedOut",
-            "ScriptFailed",
-            "UnknownError",
-        ],
-        "scriptName": str,
-        "message": str,
-        "logTail": str,
-    },
+    {"errorCode": LifecycleErrorCode, "scriptName": str, "message": str, "logTail": str},
     total=False,
 )
 
 EC2TagFilterTypeDef = TypedDict(
-    "EC2TagFilterTypeDef",
-    {"Key": str, "Value": str, "Type": Literal["KEY_ONLY", "VALUE_ONLY", "KEY_AND_VALUE"]},
-    total=False,
+    "EC2TagFilterTypeDef", {"Key": str, "Value": str, "Type": EC2TagFilterType}, total=False
 )
 
 EC2TagSetTypeDef = TypedDict(
@@ -362,9 +349,7 @@ ECSTargetTypeDef = TypedDict(
         "targetArn": str,
         "lastUpdatedAt": datetime,
         "lifecycleEvents": List["LifecycleEventTypeDef"],
-        "status": Literal[
-            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
-        ],
+        "status": TargetStatus,
         "taskSetsInfo": List["ECSTaskSetTypeDef"],
     },
     total=False,
@@ -380,7 +365,7 @@ ECSTaskSetTypeDef = TypedDict(
         "status": str,
         "trafficWeight": float,
         "targetGroup": "TargetGroupInfoTypeDef",
-        "taskSetLabel": Literal["Blue", "Green"],
+        "taskSetLabel": TargetLabel,
     },
     total=False,
 )
@@ -388,47 +373,7 @@ ECSTaskSetTypeDef = TypedDict(
 ELBInfoTypeDef = TypedDict("ELBInfoTypeDef", {"name": str}, total=False)
 
 ErrorInformationTypeDef = TypedDict(
-    "ErrorInformationTypeDef",
-    {
-        "code": Literal[
-            "AGENT_ISSUE",
-            "ALARM_ACTIVE",
-            "APPLICATION_MISSING",
-            "AUTOSCALING_VALIDATION_ERROR",
-            "AUTO_SCALING_CONFIGURATION",
-            "AUTO_SCALING_IAM_ROLE_PERMISSIONS",
-            "CODEDEPLOY_RESOURCE_CANNOT_BE_FOUND",
-            "CUSTOMER_APPLICATION_UNHEALTHY",
-            "DEPLOYMENT_GROUP_MISSING",
-            "ECS_UPDATE_ERROR",
-            "ELASTIC_LOAD_BALANCING_INVALID",
-            "ELB_INVALID_INSTANCE",
-            "HEALTH_CONSTRAINTS",
-            "HEALTH_CONSTRAINTS_INVALID",
-            "HOOK_EXECUTION_FAILURE",
-            "IAM_ROLE_MISSING",
-            "IAM_ROLE_PERMISSIONS",
-            "INTERNAL_ERROR",
-            "INVALID_ECS_SERVICE",
-            "INVALID_LAMBDA_CONFIGURATION",
-            "INVALID_LAMBDA_FUNCTION",
-            "INVALID_REVISION",
-            "MANUAL_STOP",
-            "MISSING_BLUE_GREEN_DEPLOYMENT_CONFIGURATION",
-            "MISSING_ELB_INFORMATION",
-            "MISSING_GITHUB_TOKEN",
-            "NO_EC2_SUBSCRIPTION",
-            "NO_INSTANCES",
-            "OVER_MAX_INSTANCES",
-            "RESOURCE_LIMIT_EXCEEDED",
-            "REVISION_MISSING",
-            "THROTTLED",
-            "TIMEOUT",
-            "CLOUDFORMATION_STACK_FAILURE",
-        ],
-        "message": str,
-    },
-    total=False,
+    "ErrorInformationTypeDef", {"code": ErrorCode, "message": str}, total=False
 )
 
 GenericRevisionInfoTypeDef = TypedDict(
@@ -448,9 +393,7 @@ GitHubLocationTypeDef = TypedDict(
 )
 
 GreenFleetProvisioningOptionTypeDef = TypedDict(
-    "GreenFleetProvisioningOptionTypeDef",
-    {"action": Literal["DISCOVER_EXISTING", "COPY_AUTO_SCALING_GROUP"]},
-    total=False,
+    "GreenFleetProvisioningOptionTypeDef", {"action": GreenFleetProvisioningAction}, total=False
 )
 
 InstanceInfoTypeDef = TypedDict(
@@ -472,12 +415,10 @@ InstanceSummaryTypeDef = TypedDict(
     {
         "deploymentId": str,
         "instanceId": str,
-        "status": Literal[
-            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
-        ],
+        "status": InstanceStatus,
         "lastUpdatedAt": datetime,
         "lifecycleEvents": List["LifecycleEventTypeDef"],
-        "instanceType": Literal["Blue", "Green"],
+        "instanceType": InstanceType,
     },
     total=False,
 )
@@ -488,12 +429,10 @@ InstanceTargetTypeDef = TypedDict(
         "deploymentId": str,
         "targetId": str,
         "targetArn": str,
-        "status": Literal[
-            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
-        ],
+        "status": TargetStatus,
         "lastUpdatedAt": datetime,
         "lifecycleEvents": List["LifecycleEventTypeDef"],
-        "instanceLabel": Literal["Blue", "Green"],
+        "instanceLabel": TargetLabel,
     },
     total=False,
 )
@@ -516,9 +455,7 @@ LambdaTargetTypeDef = TypedDict(
         "deploymentId": str,
         "targetId": str,
         "targetArn": str,
-        "status": Literal[
-            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
-        ],
+        "status": TargetStatus,
         "lastUpdatedAt": datetime,
         "lifecycleEvents": List["LifecycleEventTypeDef"],
         "lambdaFunctionInfo": "LambdaFunctionInfoTypeDef",
@@ -528,14 +465,7 @@ LambdaTargetTypeDef = TypedDict(
 
 LastDeploymentInfoTypeDef = TypedDict(
     "LastDeploymentInfoTypeDef",
-    {
-        "deploymentId": str,
-        "status": Literal[
-            "Created", "Queued", "InProgress", "Baking", "Succeeded", "Failed", "Stopped", "Ready"
-        ],
-        "endTime": datetime,
-        "createTime": datetime,
-    },
+    {"deploymentId": str, "status": DeploymentStatus, "endTime": datetime, "createTime": datetime},
     total=False,
 )
 
@@ -546,7 +476,7 @@ LifecycleEventTypeDef = TypedDict(
         "diagnostics": "DiagnosticsTypeDef",
         "startTime": datetime,
         "endTime": datetime,
-        "status": Literal["Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown"],
+        "status": LifecycleEventStatus,
     },
     total=False,
 )
@@ -562,9 +492,7 @@ LoadBalancerInfoTypeDef = TypedDict(
 )
 
 MinimumHealthyHostsTypeDef = TypedDict(
-    "MinimumHealthyHostsTypeDef",
-    {"type": Literal["HOST_COUNT", "FLEET_PERCENT"], "value": int},
-    total=False,
+    "MinimumHealthyHostsTypeDef", {"type": MinimumHealthyHostsType, "value": int}, total=False
 )
 
 OnPremisesTagSetTypeDef = TypedDict(
@@ -605,7 +533,7 @@ RevisionInfoTypeDef = TypedDict(
 RevisionLocationTypeDef = TypedDict(
     "RevisionLocationTypeDef",
     {
-        "revisionType": Literal["S3", "GitHub", "String", "AppSpecContent"],
+        "revisionType": RevisionLocationType,
         "s3Location": "S3LocationTypeDef",
         "gitHubLocation": "GitHubLocationTypeDef",
         "string": "RawStringTypeDef",
@@ -622,20 +550,12 @@ RollbackInfoTypeDef = TypedDict(
 
 S3LocationTypeDef = TypedDict(
     "S3LocationTypeDef",
-    {
-        "bucket": str,
-        "key": str,
-        "bundleType": Literal["tar", "tgz", "zip", "YAML", "JSON"],
-        "version": str,
-        "eTag": str,
-    },
+    {"bucket": str, "key": str, "bundleType": BundleType, "version": str, "eTag": str},
     total=False,
 )
 
 TagFilterTypeDef = TypedDict(
-    "TagFilterTypeDef",
-    {"Key": str, "Value": str, "Type": Literal["KEY_ONLY", "VALUE_ONLY", "KEY_AND_VALUE"]},
-    total=False,
+    "TagFilterTypeDef", {"Key": str, "Value": str, "Type": TagFilterType}, total=False
 )
 
 TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
@@ -675,7 +595,7 @@ TrafficRouteTypeDef = TypedDict("TrafficRouteTypeDef", {"listenerArns": List[str
 TrafficRoutingConfigTypeDef = TypedDict(
     "TrafficRoutingConfigTypeDef",
     {
-        "type": Literal["TimeBasedCanary", "TimeBasedLinear", "AllAtOnce"],
+        "type": TrafficRoutingType,
         "timeBasedCanary": "TimeBasedCanaryTypeDef",
         "timeBasedLinear": "TimeBasedLinearTypeDef",
     },
@@ -684,24 +604,7 @@ TrafficRoutingConfigTypeDef = TypedDict(
 
 TriggerConfigTypeDef = TypedDict(
     "TriggerConfigTypeDef",
-    {
-        "triggerName": str,
-        "triggerTargetArn": str,
-        "triggerEvents": List[
-            Literal[
-                "DeploymentStart",
-                "DeploymentSuccess",
-                "DeploymentFailure",
-                "DeploymentStop",
-                "DeploymentRollback",
-                "DeploymentReady",
-                "InstanceStart",
-                "InstanceSuccess",
-                "InstanceFailure",
-                "InstanceReady",
-            ]
-        ],
-    },
+    {"triggerName": str, "triggerTargetArn": str, "triggerEvents": List[TriggerEventType]},
     total=False,
 )
 
@@ -930,11 +833,7 @@ PutLifecycleEventHookExecutionStatusOutputTypeDef = TypedDict(
 
 StopDeploymentOutputTypeDef = TypedDict(
     "StopDeploymentOutputTypeDef",
-    {
-        "status": Literal["Pending", "Succeeded"],
-        "statusMessage": str,
-        "ResponseMetadata": "ResponseMetadata",
-    },
+    {"status": StopStatus, "statusMessage": str, "ResponseMetadata": "ResponseMetadata"},
     total=False,
 )
 
